@@ -79,6 +79,9 @@ void mysqlx_unregister_exception_class(SHUTDOWN_FUNC_ARGS);
 #define err_msg_invalid_attrib_key_size    10039, "Connection attribute keys cannot be longer than 32 characters"
 #define err_msg_invalid_attrib_value_size  10039, "Connection attribute keys cannot be longer than 1024 characters"
 #define err_msg_invalid_attrib_size        10040, "The connection attribute string is too long."
+#define err_msg_invalid_compression_opt    10041, "The provided compression option is not recognized."
+#define err_msg_compression_not_supported  10042, "Compression requested but the server does not support it."
+#define err_msg_compres_negotiation_failed 10043, "Compression requested but the compression algorithm negotiation failed."
 
 extern void RAISE_EXCEPTION(const int errcode, const char * const msg);
 
