@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 7                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 2006-2019 The PHP Group                                |
+  | Copyright (c) 2006-2020 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -110,7 +110,7 @@ bool Bindings::bind(const util::string& var_name, zval* var_value)
 bool Bindings::finalize(google::protobuf::RepeatedPtrField< ::Mysqlx::Datatypes::Scalar >* mutable_args)
 {
 	DBG_ENTER("Bindings::finalize");
-	assert(mutable_args->empty());
+    //assert(mutable_args->empty());
 	for (const auto& var_name_value : bound_variables) {
 		auto var_value{ var_name_value.second };
 		if (var_value == nullptr) {
