@@ -13,17 +13,18 @@
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Authors: Andrey Hristov <andrey@php.net>                             |
+  |          Filip Janiszewski <fjanisze@php.net>                        |
+  |          Darek Slusarczyk <marines@php.net>                          |
   +----------------------------------------------------------------------+
 */
 #ifndef XMYSQLND_WIREPROTOCOL_H
 #define XMYSQLND_WIREPROTOCOL_H
 
 #include "mysqlnd_api.h"
+#include "xmysqlnd/xmysqlnd_wireprotocol_types.h"
 #include "xmysqlnd/xmysqlnd_protocol_frame_codec.h"
 
-#include "proto_gen/mysqlx.pb.h"
 #include "proto_gen/mysqlx_expect.pb.h"
-#include "proto_gen/mysqlx_notice.pb.h"
 
 #include "util/strings.h"
 
@@ -31,6 +32,8 @@ namespace mysqlx {
 
 namespace drv {
 
+namespace compression { class Executor; }
+
 class xmysqlnd_session_data;
 struct st_xmysqlnd_stmt_result;
 struct st_xmysqlnd_stmt_result_meta;
@@ -41,86 +44,15 @@ struct st_xmysqlnd_pb_message_shell;
 
 MYSQLND_CSTRING xmysqlnd_field_type_name(const unsigned int type);
 
-enum xmysqlnd_client_message_type
+struct Message_context
 {
-	COM_CAPABILITIES_GET	= Mysqlx::ClientMessages_Type_CON_CAPABILITIES_GET,
-	COM_CAPABILITIES_SET	= Mysqlx::ClientMessages_Type_CON_CAPABILITIES_SET,
-	COM_CONN_CLOSE			= Mysqlx::ClientMessages_Type_CON_CLOSE,
-	COM_AUTH_START			= Mysqlx::ClientMessages_Type_SESS_AUTHENTICATE_START,
-	COM_AUTH_CONTINUE		= Mysqlx::ClientMessages_Type_SESS_AUTHENTICATE_CONTINUE,
-	COM_SESSION_RESET		= Mysqlx::ClientMessages_Type_SESS_RESET,
-	COM_SESSION_CLOSE		= Mysqlx::ClientMessages_Type_SESS_CLOSE,
-	COM_SQL_STMT_EXECUTE	= Mysqlx::ClientMessages_Type_SQL_STMT_EXECUTE,
-	COM_CRUD_FIND			= Mysqlx::ClientMessages_Type_CRUD_FIND,
-	COM_CRUD_INSERT			= Mysqlx::ClientMessages_Type_CRUD_INSERT,
-	COM_CRUD_UPDATE			= Mysqlx::ClientMessages_Type_CRUD_UPDATE,
-	COM_CRUD_DELETE			= Mysqlx::ClientMessages_Type_CRUD_DELETE,
-	COM_EXPECTATIONS_OPEN	= Mysqlx::ClientMessages_Type_EXPECT_OPEN,
-	COM_EXPECTATIONS_CLOSE	= Mysqlx::ClientMessages_Type_EXPECT_CLOSE,
-	COM_CRUD_CREATE_VIEW    = Mysqlx::ClientMessages_Type_CRUD_CREATE_VIEW,
-	COM_CRUD_MODIFY_VIEW    = Mysqlx::ClientMessages_Type_CRUD_MODIFY_VIEW,
-	COM_CRUD_DROP_VIEW      = Mysqlx::ClientMessages_Type_CRUD_DROP_VIEW,
-	COM_PREPARE_PREPARE     = Mysqlx::ClientMessages_Type_PREPARE_PREPARE,
-	COM_PREPARE_EXECUTE     = Mysqlx::ClientMessages_Type_PREPARE_EXECUTE,
-	COM_NONE                = 255
+	MYSQLND_VIO* vio;
+	XMYSQLND_PFC* pfc;
+	MYSQLND_STATS* stats;
+	MYSQLND_ERROR_INFO* error_info;
+	compression::Executor* compression_executor;
 };
 
-enum xmysqlnd_server_message_type
-{
-	XMSG_OK						    = Mysqlx::ServerMessages_Type_OK,
-	XMSG_ERROR					    = Mysqlx::ServerMessages_Type_ERROR,
-	XMSG_CAPABILITIES			    = Mysqlx::ServerMessages_Type_CONN_CAPABILITIES,
-	XMSG_AUTH_CONTINUE			    = Mysqlx::ServerMessages_Type_SESS_AUTHENTICATE_CONTINUE,
-	XMSG_AUTH_OK				    = Mysqlx::ServerMessages_Type_SESS_AUTHENTICATE_OK,
-	XMSG_NOTICE					    = Mysqlx::ServerMessages_Type_NOTICE,
-	XMSG_COLUMN_METADATA		    = Mysqlx::ServerMessages_Type_RESULTSET_COLUMN_META_DATA,
-	XMSG_RSET_ROW				    = Mysqlx::ServerMessages_Type_RESULTSET_ROW,
-	XMSG_RSET_FETCH_DONE		    = Mysqlx::ServerMessages_Type_RESULTSET_FETCH_DONE,
-	XMGS_RSET_FETCH_SUSPENDED	    = Mysqlx::ServerMessages_Type_RESULTSET_FETCH_SUSPENDED,
-	XMSG_RSET_FETCH_DONE_MORE_RSETS = Mysqlx::ServerMessages_Type_RESULTSET_FETCH_DONE_MORE_RESULTSETS,
-	XMSG_STMT_EXECUTE_OK		    = Mysqlx::ServerMessages_Type_SQL_STMT_EXECUTE_OK,
-	XMSG_RSET_FETCH_DONE_MORE_OUT   = Mysqlx::ServerMessages_Type_RESULTSET_FETCH_DONE_MORE_OUT_PARAMS,
-	XMSG_NONE = 255
-};
-
-enum xmysqlnd_stmt_warning_level
-{
-	XSTMT_WARN_NOTE		= Mysqlx::Notice::Warning_Level_NOTE,
-	XSTMT_WARN_WARNING	= Mysqlx::Notice::Warning_Level_WARNING,
-	XSTMT_WARN_ERROR	= Mysqlx::Notice::Warning_Level_ERROR,
-	XSTMT_WARN_NONE = 255,
-};
-
-enum xmysqlnd_execution_state_type
-{
-	EXEC_STATE_NONE = 0,
-	EXEC_STATE_GENERATED_INSERT_ID = 1,
-	EXEC_STATE_ROWS_AFFECTED,
-	EXEC_STATE_ROWS_FOUND,
-	EXEC_STATE_ROWS_MATCHED,
-};
-
-enum xmysqlnd_transaction_state_type
-{
-	TRX_STATE_COMMITTED = 1,
-	TRX_STATE_ROLLEDBACK,
-};
-
-enum xmysqlnd_changed_state_type
-{
-	CHG_STATE_CURRENT_SCHEMA = 1,
-	CHG_STATE_ACCOUNT_EXPIRED,
-	CHG_STATE_PRODUCED_MESSAGE,
-	CHG_STATE_CLIENT_ID_ASSIGNED,
-};
-
-enum xmysqlnd_data_model
-{
-	XMYSQLND_MODEL_TABLE,
-	XMYSQLND_MODEL_COLLECTION
-};
-
-
 
 struct st_xmysqlnd_on_warning_bind
 {
@@ -143,8 +75,6 @@ struct st_xmysqlnd_on_session_var_change_bind
 };
 
 
-
-
 struct st_xmysqlnd_msg__capabilities_get
 {
 	enum_func_status (*send_request)(st_xmysqlnd_msg__capabilities_get* msg);
@@ -155,10 +85,7 @@ struct st_xmysqlnd_msg__capabilities_get
 	enum_func_status (*init_read)(st_xmysqlnd_msg__capabilities_get* const msg,
 								  const struct st_xmysqlnd_on_error_bind on_error);
 
-	MYSQLND_VIO * vio;
-	XMYSQLND_PFC * pfc;
-	MYSQLND_STATS * stats;
-	MYSQLND_ERROR_INFO * error_info;
+	Message_context msg_ctx;
 	st_xmysqlnd_on_error_bind on_error;
 	zval* capabilities_zval;
 };
@@ -174,10 +101,7 @@ struct st_xmysqlnd_msg__capabilities_set
 
 	enum_func_status (*init_read)(st_xmysqlnd_msg__capabilities_set* const msg,
 								  const struct st_xmysqlnd_on_error_bind on_error);
-	MYSQLND_VIO * vio;
-	XMYSQLND_PFC * pfc;
-	MYSQLND_STATS * stats;
-	MYSQLND_ERROR_INFO * error_info;
+	Message_context msg_ctx;
 	st_xmysqlnd_on_error_bind on_error;
 	zval* return_value_zval;
 };
@@ -212,10 +136,7 @@ struct st_xmysqlnd_msg__auth_start
 								  const struct st_xmysqlnd_on_client_id_bind on_client_id,
 								  const struct st_xmysqlnd_on_session_var_change_bind on_session_var_change);
 
-	MYSQLND_VIO * vio;
-	XMYSQLND_PFC * pfc;
-	MYSQLND_STATS * stats;
-	MYSQLND_ERROR_INFO * error_info;
+	Message_context msg_ctx;
 	st_xmysqlnd_on_auth_continue_bind on_auth_continue;
 	st_xmysqlnd_on_warning_bind on_warning;
 	st_xmysqlnd_on_error_bind on_error;
@@ -224,30 +145,6 @@ struct st_xmysqlnd_msg__auth_start
 	zval* auth_start_response_zval;
 };
 
-#if AUTH_CONTINUE
-struct st_xmysqlnd_msg__auth_continue
-{
-	enum_func_status (*send_request)(st_xmysqlnd_msg__auth_continue* msg,
-									 const MYSQLND_CSTRING schema,
-									 const MYSQLND_CSTRING user,
-									 const MYSQLND_CSTRING password,
-									 const MYSQLND_CSTRING salt);
-
-	enum_func_status (*read_response)(st_xmysqlnd_msg__auth_continue* msg,
-									  zval * auth_continue_response);
-
-	enum_func_status (*init_read)(st_xmysqlnd_msg__auth_continue* const msg,
-								  const struct st_xmysqlnd_on_error_bind on_error);
-
-	MYSQLND_VIO * vio;
-	XMYSQLND_PFC * pfc;
-	MYSQLND_STATS * stats;
-	MYSQLND_ERROR_INFO * error_info;
-	st_xmysqlnd_on_error_bind on_error;
-	zval* auth_continue_response_zval;
-};
-#endif
-
 struct st_xmysqlnd_meta_field_create_bind
 {
 	st_xmysqlnd_result_field_meta* (*create)(void * context);
@@ -303,10 +200,7 @@ struct st_xmysqlnd_on_resultset_end_bind
 
 struct st_xmysqlnd_result_set_reader_ctx
 {
-	MYSQLND_VIO * vio;
-	XMYSQLND_PFC * pfc;
-	MYSQLND_STATS * stats;
-	MYSQLND_ERROR_INFO * error_info;
+	Message_context msg_ctx;
 
 	st_xmysqlnd_meta_field_create_bind create_meta_field;
 
@@ -364,10 +258,7 @@ struct st_xmysqlnd_msg__session_reset
 		st_xmysqlnd_msg__session_reset* const msg,
 		const st_xmysqlnd_on_error_bind on_error);
 
-	MYSQLND_VIO* vio;
-	XMYSQLND_PFC* pfc;
-	MYSQLND_STATS* stats;
-	MYSQLND_ERROR_INFO* error_info;
+	Message_context msg_ctx;
 
 	st_xmysqlnd_on_error_bind on_error;
 
@@ -384,10 +275,7 @@ struct st_xmysqlnd_msg__session_close
 		st_xmysqlnd_msg__session_close* const msg,
 		const st_xmysqlnd_on_error_bind on_error);
 
-	MYSQLND_VIO* vio;
-	XMYSQLND_PFC* pfc;
-	MYSQLND_STATS* stats;
-	MYSQLND_ERROR_INFO* error_info;
+	Message_context msg_ctx;
 
 	st_xmysqlnd_on_error_bind on_error;
 };
@@ -401,10 +289,7 @@ struct st_xmysqlnd_msg__connection_close
 	enum_func_status (*init_read)(st_xmysqlnd_msg__connection_close* const msg,
 								  const st_xmysqlnd_on_error_bind on_error);
 
-	MYSQLND_VIO * vio;
-	XMYSQLND_PFC * pfc;
-	MYSQLND_STATS * stats;
-	MYSQLND_ERROR_INFO * error_info;
+	Message_context msg_ctx;
 
 	st_xmysqlnd_on_error_bind on_error;
 };
@@ -418,10 +303,7 @@ struct st_xmysqlnd_msg__expectations_open
 	enum_func_status (*init_read)(st_xmysqlnd_msg__expectations_open* const msg,
 		const st_xmysqlnd_on_error_bind on_error);
 
-	MYSQLND_VIO* vio;
-	XMYSQLND_PFC* pfc;
-	MYSQLND_STATS* stats;
-	MYSQLND_ERROR_INFO* error_info;
+	Message_context msg_ctx;
 
 	st_xmysqlnd_on_error_bind on_error;
 
@@ -448,20 +330,14 @@ struct st_xmysqlnd_msg__expectations_close
 	enum_func_status (*init_read)(st_xmysqlnd_msg__expectations_close* const msg,
 		const st_xmysqlnd_on_error_bind on_error);
 
-	MYSQLND_VIO* vio;
-	XMYSQLND_PFC* pfc;
-	MYSQLND_STATS* stats;
-	MYSQLND_ERROR_INFO* error_info;
+	Message_context msg_ctx;
 
 	st_xmysqlnd_on_error_bind on_error;
 };
 
 struct st_xmysqlnd_result_ctx
 {
-	MYSQLND_VIO * vio;
-	XMYSQLND_PFC * pfc;
-	MYSQLND_STATS * stats;
-	MYSQLND_ERROR_INFO * error_info;
+	Message_context msg_ctx;
 
 	st_xmysqlnd_on_warning_bind on_warning;
 	st_xmysqlnd_on_error_bind on_error;
@@ -482,10 +358,7 @@ struct st_xmysqlnd_msg__collection_add
 	enum_func_status(*init_read)(st_xmysqlnd_msg__collection_add* const msg,
 		const struct st_xmysqlnd_on_error_bind on_error);
 
-	MYSQLND_VIO * vio;
-	XMYSQLND_PFC * pfc;
-	MYSQLND_STATS * stats;
-	MYSQLND_ERROR_INFO * error_info;
+	Message_context msg_ctx;
 
 	struct st_xmysqlnd_on_error_bind on_error;
 };
@@ -517,10 +390,7 @@ struct st_xmysqlnd_msg__prepare_prepare
 	enum_func_status(*init_read)(st_xmysqlnd_msg__prepare_prepare* const msg,
 		const struct st_xmysqlnd_on_error_bind on_error);
 
-	MYSQLND_VIO * vio;
-	XMYSQLND_PFC * pfc;
-	MYSQLND_STATS * stats;
-	MYSQLND_ERROR_INFO * error_info;
+	Message_context msg_ctx;
 
 	struct st_xmysqlnd_on_error_bind on_error;
 };
@@ -535,10 +405,7 @@ struct st_xmysqlnd_msg__prepare_execute
 	enum_func_status(*init_read)(st_xmysqlnd_msg__prepare_execute* const msg,
 		const struct st_xmysqlnd_on_error_bind on_error);
 
-	MYSQLND_VIO * vio;
-	XMYSQLND_PFC * pfc;
-	MYSQLND_STATS * stats;
-	MYSQLND_ERROR_INFO * error_info;
+	Message_context msg_ctx;
 
 	struct st_xmysqlnd_on_error_bind on_error;
 };
@@ -557,10 +424,7 @@ struct st_xmysqlnd_msg__collection_ud
 	enum_func_status (*init_read)(st_xmysqlnd_msg__collection_ud* const msg,
 								  const struct st_xmysqlnd_on_error_bind on_error);
 
-	MYSQLND_VIO * vio;
-	XMYSQLND_PFC * pfc;
-	MYSQLND_STATS * stats;
-	MYSQLND_ERROR_INFO * error_info;
+	Message_context msg_ctx;
 
 	struct st_xmysqlnd_on_error_bind on_error;
 };
@@ -611,35 +475,30 @@ struct st_xmysqlnd_msg__view_cmd
 
 struct st_xmysqlnd_message_factory
 {
-	MYSQLND_VIO * vio;
-	XMYSQLND_PFC * pfc;
-	MYSQLND_STATS * stats;
-	MYSQLND_ERROR_INFO * error_info;
-	struct st_xmysqlnd_msg__capabilities_get	(*get__capabilities_get)(const st_xmysqlnd_message_factory* const factory);
-	struct st_xmysqlnd_msg__capabilities_set	(*get__capabilities_set)(const st_xmysqlnd_message_factory* const factory);
-	struct st_xmysqlnd_msg__auth_start			(*get__auth_start)(const st_xmysqlnd_message_factory* const factory);
-#if AUTH_CONTINUE
-	struct st_xmysqlnd_msg__auth_continue		(*get__auth_continue)(const st_xmysqlnd_message_factory* const factory);
-#endif
-	struct st_xmysqlnd_msg__sql_stmt_execute	(*get__sql_stmt_execute)(const st_xmysqlnd_message_factory* const factory);
+	Message_context msg_ctx;
+	st_xmysqlnd_msg__capabilities_get	(*get__capabilities_get)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__capabilities_set	(*get__capabilities_set)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__auth_start			(*get__auth_start)(st_xmysqlnd_message_factory* factory);
 
-	st_xmysqlnd_msg__session_reset (*get__session_reset)(const st_xmysqlnd_message_factory* const factory);
-	st_xmysqlnd_msg__session_close (*get__session_close)(const st_xmysqlnd_message_factory* const factory);
-	struct st_xmysqlnd_msg__connection_close	(*get__connection_close)(const st_xmysqlnd_message_factory* const factory);
-	st_xmysqlnd_msg__expectations_open (*get__expectations_open)(const st_xmysqlnd_message_factory* const factory);
-	st_xmysqlnd_msg__expectations_close (*get__expectations_close)(const st_xmysqlnd_message_factory* const factory);
-	struct st_xmysqlnd_msg__collection_add	    (*get__collection_add)(const st_xmysqlnd_message_factory* const factory);
-	struct st_xmysqlnd_msg__collection_ud		(*get__collection_ud)(const st_xmysqlnd_message_factory* const factory);
-	struct st_xmysqlnd_msg__sql_stmt_execute	(*get__collection_read)(const st_xmysqlnd_message_factory* const factory);
-	struct st_xmysqlnd_msg__table_insert		(*get__table_insert)(const st_xmysqlnd_message_factory* const factory);
-	st_xmysqlnd_msg__view_cmd                   (*get__view_create)(const st_xmysqlnd_message_factory * const factory);
-	st_xmysqlnd_msg__view_cmd                   (*get__view_alter)(const st_xmysqlnd_message_factory * const factory);
-	st_xmysqlnd_msg__view_cmd                   (*get__view_drop)(const st_xmysqlnd_message_factory * const factory);
-	st_xmysqlnd_msg__prepare_prepare            (*get__prepare_prepare)(const st_xmysqlnd_message_factory* const factory);
-	st_xmysqlnd_msg__prepare_execute            (*get__prepare_execute)(const st_xmysqlnd_message_factory* const factory);
+	st_xmysqlnd_msg__sql_stmt_execute	(*get__sql_stmt_execute)(st_xmysqlnd_message_factory* factory);
+
+	st_xmysqlnd_msg__session_reset (*get__session_reset)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__session_close (*get__session_close)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__connection_close	(*get__connection_close)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__expectations_open (*get__expectations_open)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__expectations_close (*get__expectations_close)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__collection_add	    (*get__collection_add)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__collection_ud		(*get__collection_ud)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__sql_stmt_execute	(*get__collection_read)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__table_insert		(*get__table_insert)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__view_cmd                   (*get__view_create)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__view_cmd                   (*get__view_alter)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__view_cmd                   (*get__view_drop)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__prepare_prepare            (*get__prepare_prepare)(st_xmysqlnd_message_factory* factory);
+	st_xmysqlnd_msg__prepare_execute            (*get__prepare_execute)(st_xmysqlnd_message_factory* factory);
 };
 
-struct st_xmysqlnd_message_factory xmysqlnd_get_message_factory(const st_xmysqlnd_level3_io* const io, MYSQLND_STATS * stats, MYSQLND_ERROR_INFO * error_info);
+st_xmysqlnd_message_factory get_message_factory(Message_context msg_ctx);
 
 void xmysqlnd_shutdown_protobuf_library();
 
